Module jemalloc_ctl::arenas [−][src]
Arena operations.
Structs
| NArenas |
A type providing access to the current limit on the number of arenas. |
Functions
| narenas |
Returns the current limit on the number of arenas. |