Function jemalloc_ctl::opt::narenas[][src]

pub fn narenas() -> Result<c_uint>

Returns the maximum number of arenas to use for automatic multiplexing of threads and arenas.

The default is four times the number of CPUs, or one if there is a single CPU.

Examples

extern crate jemallocator;
extern crate jemalloc_ctl;

#[global_allocator]
static ALLOC: jemallocator::Jemalloc = jemallocator::Jemalloc;

fn main() {
    println!("number of arenas: {}", jemalloc_ctl::opt::narenas().unwrap());
}