Struct jemalloc_ctl::opt::Junk [−][src]
pub struct Junk(_);
A type providing access to jemalloc's junk filling mode.
Requires --enable-fill to have been specified during build configuration.
If set to "alloc", each byte of uninitialized allocated memory will be set to 0x5a. If set to
"free", each byte of deallocated memory will be set to 0x5a. If set to "true", both allocated
and deallocated memory will be initialized, and if set to "false" junk filling will be disabled.
This is intended for debugging and will impact performance negatively.
The default is "false", unless --enable-debug was specified during build configuration, in
which case the default is "true".
Examples
extern crate jemallocator; extern crate jemalloc_ctl; use jemalloc_ctl::opt::Junk; #[global_allocator] static ALLOC: jemallocator::Jemalloc = jemallocator::Jemalloc; fn main() { let junk = Junk::new().unwrap(); println!("junk filling: {}", junk.get().unwrap()); }
Methods
impl Junk[src]
impl Junkpub fn new() -> Result<Junk>[src]
pub fn new() -> Result<Junk>Returns a new Junk.
pub fn get(&self) -> Result<&'static str>[src]
pub fn get(&self) -> Result<&'static str>Returns jemalloc's junk filling mode.