Struct jemalloc_ctl::opt::LgTcacheMax [−][src]
pub struct LgTcacheMax(_);
A type providing access to the maximum size class (log base 2) to cache in the thread-specific cache (tcache).
At a minimum, all small size classes are cached, and at a maximum all large size classes are cached. The default maximum is 32 KiB (2^15).
Examples
use jemalloc_ctl::opt::LgTcacheMax; let lg_tcache_max = LgTcacheMax::new().unwrap(); println!("max cached allocation size: {}", 1 << lg_tcache_max.get().unwrap());
Methods
impl LgTcacheMax[src]
impl LgTcacheMaxpub fn new() -> Result<LgTcacheMax>[src]
pub fn new() -> Result<LgTcacheMax>Returns a new LgTcacheMax.
pub fn get(&self) -> Result<usize>[src]
pub fn get(&self) -> Result<usize>Returns the maximum cached size class.