Module jemalloc_ctl::stats [−][src]
Global allocator statistics.
jemalloc tracks a wide variety of statistics. Many of them are cached, and only refreshed when
the jemalloc "epoch" is advanced. See the Epoch type for more information.
Structs
| Active |
A type providing access to the total number of bytes in active pages allocated by the application. |
| Allocated |
A type providing access to the total number of bytes allocated by the application. |
| Mapped |
A type providing access to the total number of bytes in active extents mapped by the allocator. |
| Metadata |
A type providing access to the total number of bytes dedicated to jemalloc metadata. |
| Resident |
A type providing access to the total number of bytes in physically resident data pages mapped by the allocator. |
| Retained |
A type providing access to the total number of bytes in virtual memory mappings that were retained rather than being
returned to the operating system via e.g. |
Functions
| active |
Returns the total number of bytes in active pages allocated by the application. |
| allocated |
Returns the total number of bytes allocated by the application. |
| mapped |
Returns the total number of bytes in active extents mapped by the allocator. |
| metadata |
Returns the total number of bytes dedicated to jemalloc metadata. |
| resident |
Returns the total number of bytes in physically resident data pages mapped by the allocator. |
| retained |
Returns the total number of bytes in virtual memory mappings that were retained rather than being returned to the
operating system via e.g. |