Function jemalloc_ctl::stats::retained[][src]

pub fn retained() -> Result<usize>

Returns the total number of bytes in virtual memory mappings that were retained rather than being returned to the operating system via e.g. munmap(2).

Retained virtual memory is typically untouched, decommitted, or purged, so it has no strongly associated physical memory. Retained memory is excluded from mapped memory statistics, e.g. mapped.

This statistic is cached, and is only refreshed when the epoch is advanced. See the epoch type for more information.

This corresponds to stats.retained in jemalloc's API.

Examples

extern crate jemallocator;
extern crate jemalloc_ctl;

#[global_allocator]
static ALLOC: jemallocator::Jemalloc = jemallocator::Jemalloc;

fn main() {
    jemalloc_ctl::epoch().unwrap();
    println!("{} bytes of total retained data", jemalloc_ctl::stats::retained().unwrap());
}