Function jemalloc_ctl::stats_print::stats_print[][src]

pub fn stats_print<W>(writer: W, options: Options) -> Result<()> where
    W: Write

Writes allocator statistics.

The information is the same that can be retrieved by the individual lookup methods in this crate, but all done at once.