Struct jemalloc_ctl::stats_print::Options [−][src]
pub struct Options {
pub json_format: bool,
pub skip_constants: bool,
pub skip_merged_arenas: bool,
pub skip_per_arena: bool,
pub skip_bin_size_classes: bool,
pub skip_large_size_classes: bool,
pub skip_mutex_statistics: bool,
// some fields omitted
}Statistics configuration.
All options default to false.
Fields
json_format: bool
If set, the output will be JSON-formatted.
This corresponds to the J character.
skip_constants: bool
If set, information that never changes during execution will be skipped.
This corresponds to the g character.
skip_merged_arenas: bool
If set, merged information about arenas will be skipped.
This corresponds to the m character.
skip_per_arena: bool
If set, information about individual arenas will be skipped.
This corresponds to the a character.
skip_bin_size_classes: bool
If set, information about individual size classes for bins will be skipped.
This corresponds to the b character.
skip_large_size_classes: bool
If set, information about individual size classes for large objects will be skipped.
This corresponds to the l character.
skip_mutex_statistics: bool
If set, mutex statistics will be skipped.
This corresponds to the x character.