Function jemalloc_ctl::opt::tcache [] [src]

pub fn tcache() -> Result<bool>

Determines if thread-local allocation caching is enabled.

Thread-specific caching allows many allocations to be satisfied without performing any thread synchronization, at the cost of increased memory use. This is enabled by default.

Examples

println!("thread-local caching: {}", jemalloc_ctl::opt::tcache().unwrap());