Struct jemalloc_ctl::opt::Tcache [] [src]

pub struct Tcache(_);

A type providing access to thread-local allocation caching behavior.

Thread-specific caching allows many allocations to be satisfied without performing any thread synchronization, at the cost of increased memory use. This is enabled by default.

Examples

use jemalloc_ctl::opt::Tcache;

let tcache = Tcache::new().unwrap();

println!("thread-local caching: {}", tcache.get().unwrap());

Methods

impl Tcache
[src]

[src]

Returns a new Tcache.

[src]

Returns the thread-local caching behavior.