Struct jemalloc_ctl::Version [−][src]
pub struct Version(_);
A type providing access to the jemalloc version string.
Note
The version of jemalloc currently shipped with the Rust distribution has a bogus version string.
Example
use jemalloc_ctl::Version; let version = Version::new().unwrap(); println!("jemalloc version {}", version.get().unwrap());
Methods
impl Version[src]
impl Versionpub fn new() -> Result<Version>[src]
pub fn new() -> Result<Version>Returns a new Version.
pub fn get(&self) -> Result<&'static str>[src]
pub fn get(&self) -> Result<&'static str>Returns the jemalloc version string.